`estimate.prev` <-
function (clust, N=seq(100,500,50), R=Inf, U=FALSE, dist.func="rdist.earth", miles=FALSE, lang="en", progression=TRUE, merge.result=FALSE, var.clust=c("x","y","n","nweight","obs.prevalence","urban.area","city.name"), urban.area.code="in urban area")
{
	begin.t <- Sys.time()
	require(fields)
	#Vrification langue
	if (lang=="fr") lg <- 2
	else lg <- 1
	if (progression) message(c("Beginning of calculations: ","Dbut des calculs : ")[lg],format(begin.t,"%X"))
	#Vrifications
	if (!is.numeric(clust[[var.clust[1]]])) stop(var.clust[1],c(" (x coordinate) must be numeric."," (coordonnes x) doit tre numrique.")[lg])
	if (!is.numeric(clust[[var.clust[2]]])) stop(var.clust[2],c(" (y coordinate) must be numeric."," (coordonnes y) doit tre numrique.")[lg])
	if (!is.numeric(clust[[var.clust[3]]])) stop(var.clust[3],c(" (number of persons by cluster) must be numeric."," (nombre de personnes par cluster) doit tre numrique.")[lg])
	if (!is.numeric(clust[[var.clust[4]]])) stop(var.clust[4],c(" (weighted total of persons by cluster) must be numeric."," (total pondrs du nombre de personnes par cluster) doit tre numrique.")[lg])
	if (!is.numeric(clust[[var.clust[5]]])) stop(var.clust[5],c(" (observed prevalence by cluster) must be numeric."," (prvalence observe par cluster) doit tre numrique.")[lg])
	if (!is.logical(U) & U!=2) stop(c("U must be TRUE, FALSE or 2.","U doit tre TRUE, FALSE ou 2.")[lg])
	if ((U | U==2) & length(clust[[var.clust[6]]])==0) stop(var.clust[6],c(" (urban area) must be specified."," (milieu de rsidence recod) doit tre spcifie.")[lg])
	if ((U | U==2) & length(clust[[var.clust[7]]])==0) stop(var.clust[7],c(" (city name) must be specified."," (nom des villes) doit tre spcifie.")[lg])
	if ((U | U==2) & !is.factor(clust[[var.clust[6]]])) clust[[var.clust[6]]] <- as.factor(clust[[var.clust[6]]])
	if ((U | U==2) & length(clust[clust[[var.clust[6]]]==urban.area.code,][[var.clust[6]]])==0) stop(var.clust[6],c(" must contain at least a cluster where "," doit contenir au moins un cluster tel que ")[lg],var.clust[[6]],c(" is equal to '"," est gal  '")[lg],urban.area.code,"'.")
	if ((U | U==2) & !is.character(clust[[var.clust[7]]])) clust[[var.clust[7]]] <- as.character(clust[[var.clust[7]]])
	if(!is.numeric(R)) stop(c("R must be a number or a list of numbers.","R doit tre un nombre ou une liste de nombres.")[lg])
	if(!is.numeric(N)) stop(c("N must be a number or a list of numbers.","N doit tre un nombre ou une liste de nombres.")[lg])
	if (dist.func!="rdist" & dist.func!="rdist.earth") stop(c("dist.func must be 'rdist' or 'rdist.earth'.","dist.func doit tre gal  'rdist' ou  'rdist.earth'.")[lg])
	if (dist.func=="rdist.earth" & !is.logical(miles)) stop(c("'miles' must be TRUE or FALSE.","'miles' doit tre TRUE or FALSE.")[lg])
	N <- sort(N,decreasing=TRUE)
	R <- sort(R,decreasing=TRUE)
	#Calcul de la matrice des distances
	coord.clust <- data.frame(clust[[var.clust[1]]],clust[[var.clust[2]]])
	names(coord.clust) <- c("x","y")
	if (dist.func=="rdist.earth")
		distances <- rdist.earth(coord.clust, miles=miles)
	else
		distances <- rdist(coord.clust)
	#Prparation des nouvelles variables
	clust$est.prevalence <- as.numeric(NA)
	clust$circle.count <- as.numeric(NA)
	clust$circle.radius <- as.numeric(NA)
	clust$circle.nb.clusters <- as.integer(NA)
	clust$quality.indicator <- as.numeric(NA)
	clust$N.parameter <- as.numeric(NA)
	clust$R.parameter <- as.numeric(NA)
	clust$U.parameter <- as.numeric(NA)
	result <- data.frame()
	if (U | U==2) U.param <- length(table(clust[[var.clust[7]]]))
	#Calculs pour chaque cluster
	for (i in 1:length(clust[[1]])) {
		one.clust <- clust[i,]
		temp <- clust
		temp$dist <- distances[i,]
		temp <- temp[order(temp$dist),]
		#Restriction au mme milieu de rsidence, et mme ville si dans agglo urbaine
		if (U | U==2) {
			temp.U <- temp[temp[[var.clust[6]]]==one.clust[[var.clust[6]]][1],]
			if (one.clust[[var.clust[6]]][1]==urban.area.code)
				temp.U <- temp.U[temp.U[[var.clust[7]]]==one.clust[[var.clust[7]]][1],]
			temp.U$cum.n <- cumsum (temp.U[[var.clust[3]]])
		}
		#Calculs sans paramtre U
		if (!U | U==2) {
			temp$cum.n <- cumsum (temp[[var.clust[3]]])
			for (j in N) {
				if(length(temp[temp$cum.n>=j,]$cum.n)==0)
					maxi <- Inf
					else maxi <- min(temp[temp$cum.n>=j,]$cum.n)
				temp <- temp[temp$cum.n<=maxi,]
				for (k in R) {
					temp2 <- temp[temp$dist<=k,]
					one.result <- one.clust
					one.result$est.prevalence <- weighted.mean(temp2[[var.clust[5]]],temp2[[var.clust[4]]],na.rm=TRUE)
					one.result$circle.count <- sum(temp2[[var.clust[3]]])
					one.result$circle.radius <- max(temp2$dist)
					one.result$circle.nb.clusters <- length(temp2$dist)
					one.result$quality.indicator <- one.result$circle.radius^2/sqrt(one.result$circle.count)
					one.result$N.parameter <- j
					one.result$R.parameter <- k
					one.result$U.parameter <- 0
					result <- rbind(result,one.result)
				}
			}
		}
		#Calculs pour le paramtre U
		if (U | U==2) {
			for (j in N) {
				if(length(temp.U[temp.U$cum.n>=j,]$cum.n)==0)
					maxi <- Inf
					else maxi <- min(temp.U[temp.U$cum.n>=j,]$cum.n)
				temp.U <- temp.U[temp.U$cum.n<=maxi,]
				for (k in R) {
					temp2.U <- temp.U[temp.U$dist<=k,]
					one.result <- one.clust
					one.result$est.prevalence <- weighted.mean(temp2.U[[var.clust[5]]],temp2.U[[var.clust[4]]],na.rm=TRUE)
					one.result$circle.count <- sum(temp2.U[[var.clust[3]]])
					one.result$circle.radius <- max(temp2.U$dist)
					one.result$circle.nb.clusters <- length(temp2.U$dist)
					one.result$quality.indicator <- one.result$circle.radius^2/sqrt(one.result$circle.count)
					one.result$N.parameter <- j
					one.result$R.parameter <- k
					one.result$U.parameter <- U.param
					result <- rbind(result,one.result)
				}
			}
		}
		if (progression & i%%25==0) message("Cluster ",i,c(" of "," sur ")[lg],length(clust[[1]]),c(" finished."," termin.")[lg]," (",format(Sys.time(),"%X"),")")
	}
	#Trier les rsultats
	result <- result[order(result$U.parameter,result$N.parameter,result$R.parameter),]
	#Affichage progression
	end.t <- Sys.time()
	if (progression) message(c("\nEnd of calculations: ","\nFin des calculs : ")[lg],format(end.t,"%X"))
	if (progression) message(c("Time of calculations: ","Temp de calcul : ")[lg],round(as.numeric(end.t-begin.t),digits=2)," ",attr(end.t-begin.t,"units"),".")
	#Rsultats
	if (merge.result) result <- merge.prev(result)
	return(result)
}

