`krige.prev` <-
function (data, formula=est.prevalence~1, locations=~x+y, type="ask", boundary=NULL, cell.size=0.05, ask.cell.size=TRUE, lang="en", model=vgm(1,"Exp",1), idp=2, show.variogram=TRUE, ...)
{
	#NB : pour voir les diffrents types de modles de variogrammes : show.vgms()
	#Variable type : si ask, essaye de fitter le variogramme exprimental  partir de model et propose  l'utilsateur, si auto, essaye de fitter et prend directement le variogramme fitt, si model, prend directement model, si idw, ralise une interpolation idw.
	#Variable formula : peut-tre une liste de formules afin de raliser plusieurs estimations  la suite avec la mme grille pour pouvoir les reprsenter ensuite. Si plusieurs formules sont proposes, le type model sera dsactiv.
	require('gstat')
	#Vrification langue
	if (lang=="fr") lg <- 2
	else lg <- 1
	#Vrifications et prparation des donnes
	if (class(formula)=="formula") formula <- c(formula)
	if (!is.list(formula)) stop(c("formula must be a formula or a list of formulas.","formula doit tre une formule ou une liste de formules.")[lg])
	for (i in 1:length(formula)) if(class(formula[[i]])!="formula") stop(c("formula must be a formula or a list of formulas.","formula doit tre une formule ou une liste de formules.")[lg])
	termes <- attr(terms(locations),"term.labels")
	if (length(termes)!=2) stop(c("Only two dimensions are dealt with. Please, modify formula.","Seules deux dimensions sont prises en charge. Merci de modifier formula.")[lg])
	if (!is.null(boundary)) {
		#Si boundary contient les mmes variables que la premire formule, alors on prend ces variables. Sinon, on prend x et y. Sinon erreur.
		if (length(boundary[[termes[1]]])>0 & length(boundary[[termes[2]]])>0)
			boundary <- data.frame(boundary[[termes[1]]],boundary[[termes[2]]])
		else if (length(boundary[['x']])>0 & length(boundary[['y']])>0) {
			boundary <- data.frame(boundary[['x']],boundary[['y']])
			message(termes[1]," & ",termes[2],c(" are not informed in boundary. X and y were taken."," sont non renseigns dans boundary. x et y ont t pris  la place.")[lg])
		} else
			stop(c("boundary contains neither the terms specified in formula, nor variables X and Y.","boundary ne contient ni les termes spcifis dans formula, ni de variables x et y.")[lg])
		names(boundary) <- termes
	}
	if (!any(type==c("ask","auto","model","idw"))) stop(c("type can take only one of the following values: ask, auto, model, idw.","type ne peut prendre qu'une des valeurs suivantes : ask, auto, model, idw.")[lg])
	nb.krige <- length(formula)
	if (type!= "idw" & any(class(model)=="variogramModel")) model <- rep(list(model),nb.krige)
	if (type!= "idw") for (i in 1:nb.krige) if (!any(class(model[[i]])=='variogramModel')) stop(c("model must be a object or a list of objects of class 'variogramModel'. See help (vgm).","model doit tre un objet ou une liste d'objets de la classe 'variogramModel'. Voir help(vgm).")[lg])
	if (type!='idw' & length(model)!=nb.krige) stop(c("formula and model must have the same number of objects.","formula et model doivent avoir le mme nombre d'objets.")[lg])
	if (type== 'idw' & length(idp)==1) {
		if (!is.numeric(idp)) stop(c("idp must be numeric.","idp doit tre numrique.")[lg])
		idp <- rep(idp, nb.krige)
	}
	if (type=='idw' & length(idp)!=nb.krige) stop(c("formula and idp must have the same number of objects.","formula et idp doivent avoir le mme nombre d'objets.")[lg])
	#Dfinition de la grille
	if (is.null(boundary)) {
		ok <- FALSE
		
		max.x <- max(data[[termes[1]]])
		min.x <- min(data[[termes[1]]])
		max.y <- max(data[[termes[2]]])
		min.y <- min(data[[termes[2]]])
	} else {
		max.x <- max(boundary[[1]])
		min.x <- min(boundary[[1]])
		max.y <- max(boundary[[2]])
		min.y <- min(boundary[[2]])
	}
	repeat {
		nb.cells.x = (max.x-min.x)%/%cell.size+1
		nb.cells.y = (max.y-min.y)%/%cell.size+1
		message(c("A cell size of ","Une taille de cellule de ")[lg],cell.size,c(" induces a grid of "," induit une grille de ")[lg],nb.cells.x,"x",nb.cells.y,c(" cells."," cellules.")[lg])
		if (!ask.cell.size) break
		message(c("Is that appropriate to you?","Cela vous convient-il ?")[lg])
		ok <- menu(c(c("Yes","Oui")[lg],c("No","Non")[lg]))
		if (ok==1) break
		message(c("Enter a new value for cell size :","Entrez une nouvelle valeur de taille de cellule :")[lg])
		cell.size <- edit(cell.size)
		next
	}
	grid_topo <- GridTopology(c(min.x,min.y),c(cell.size,cell.size),c(nb.cells.x,nb.cells.y))
	locations.data <- as.data.frame(coordinates(grid_topo))
	names(locations.data) <- termes
	#Prparation data
	coordinates(data) <- locations
	coordinates(locations.data) <- locations
	#Interpolation
	for (i in 1:length(formula)) {
		nom <- paste(formula[[i]][2],formula[[i]][1],formula[[i]][3])
		message("\n-------- ",nom," --------\n")
		if (type=="idw") {
			#IDW
			result.one <- idw(formula[[i]], data,locations.data, idp=idp[[i]], ...)
		} else {
			#KRIGEAGE
			sample.vario <- variogram(formula[[i]],data)
			if (any(type==c("ask","auto")))
				model[[i]] <- fit.variogram(sample.vario,model=model[[i]])
			if (type=="ask") {
				X11()
				repeat {
					plot(x=sample.vario$dist,y=sample.vario$gamma,xlab="Distance",ylab="Semi-variance",main=paste(c("Semi-variogram","Semi-variogramme")[lg],nom))
					lines.default(variogramLine(model[[i]],maxdist=max(sample.vario$dist)))
					message("\n--- ",nom," ---\n")
					print(model[[i]])
					message(c("\nIs this variogram model appropriate?","\nCe modle de variogramme convient-il ?")[lg])
					ok <- menu(c(c("Yes","Oui")[lg],c("No","Non")[lg]))
					if (ok==1) break
					message(c("Input a new model.","Entrez un nouveau modle.")[lg])
					model[[i]] <- edit(model[[i]])
					class(model[[i]]) <- c('variogramModel', 'data.frame')
					next
				}
				dev.off()
			}
			message(c("Variogram model used:","Modle de variogramme utilis :")[lg])
			print(model[[i]])
			result.one <- krige(formula[[i]], data,locations.data, model=model[[i]], ...)
			if (i==1) {
				liste.noms <- list(nom)
				liste.sample.vario <- list(sample.vario)
				liste.model <- list(model[[i]])
			} else {
				liste.noms[[i]] <- nom
				liste.sample.vario[[i]] <- sample.vario
				liste.model[[i]] <- model[[i]]
			}
		}
		gridded(result.one) <- TRUE
		temp <- attr(result.one, 'data')
		nom.var <- attr(terms(formula[[i]]),'variables')[[2]]
		names(temp) <- c(paste(nom.var,'.pred',sep=''),paste(nom.var,'.var',sep=''))
		if (!is.null(boundary)) {
			if (i==1) {
				temp.coord <- attr(result.one, 'coords')
				is.inside <- point.in.polygon(temp.coord[,1],temp.coord[,2],boundary[,1],boundary[,2])
			}
			temp[is.inside==0,1]<-NA
			temp[is.inside==0,2]<-NA
		}
		if (i==1) {
			attr(result.one, 'data') <- temp
			result <- result.one
		} else {
			data.result <- attr(result, 'data')
			data.result <- cbind(data.result,temp)
			attr(result, 'data') <- data.result
		}
	}
	if (show.variogram & type!="idw") {
		for (k in 1:length(liste.noms)) {
			X11()
			plot(x=liste.sample.vario[[k]]$dist,y=liste.sample.vario[[k]]$gamma,xlab="Distance",ylab="Semi-variance",main=liste.noms[[i]])
			lines.default(variogramLine(liste.model[[k]],maxdist=max(liste.sample.vario[[k]]$dist)))
		}
	}
	return(result)

}

