\name{calcul.dist.cities}
\alias{calcul.dist.cities}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Calcule la distance  la ville la plus proche et recode le milieu de rsidence.}
\description{
Cette fonction calcule la distance de chaque cluster  la ville la plus proche et recode le milieu de rsidence selon l'appartenance ou non  une agglomration urbaine. Un cluster est considr comme appartenant  une agglomration urbaine s'il est  la fois urbain et situ  une distance infrieure  \code{dist} de la ville la plus proche.
}
\usage{
calcul.dist.cities(
   clust,
   cities,
   dist = 15,
   type = "ask",
   lang = "en",
   var.cities = c("x", "y", "city.name"),
   var.clust = c("x", "y", "residence"),
   urban.code = "Urban",
   dist.func = "rdist.earth",
   miles = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{clust}{data.frame. Une observation par cluster. Typiquement le rsultat de la fonction \code{\link{make.clust.dbf}}.}
  \item{cities}{data.frame. Une observation par ville. Typiquement le rsultat de la fonction \code{\link{make.cities.csv}}.}
  \item{dist}{numeric. Distance en dessous de laquelle un cluster urbain est considr comme appartenant  une agglomration urbaine. Il ne s'agit pas de la taille d'une ville mais d'un paramtre permettant de distinguer les clusters urbains d'une agglomration urbaine des autres clusters urbains. Voir les dtails pour l'unit  utiliser.}
  \item{type}{character. Prend la valeur \code{'ask'} ou \code{'all'}. Voir les dtails.}
  \item{lang}{character. Permet de choisir la langue des messages utilisateur. \code{fr} pour le franais, \code{en} pour l'anglais.}
  \item{var.cities}{character vector. Liste spcifiant, dans l'ordre, le nom des variables de \code{cities} correspondant  la longitude, la latitude et le nom de chaque ville.}
  \item{var.clust}{character vector. Liste spcifiant, dans l'ordre, le nom des variables de \code{clust} correspondant  la longitude, la latitude et le milieu de rsidence. Le milieu de rsidence doit tre de type factor ou character.}
  \item{urban.code}{character. Valeur texte spcifiant comment est code la valeur \emph{urbain} de la variable \emph{milieu de rsidence} dans \code{clust}.}
  \item{dist.func}{character. Valeur texte spcifiant le nom de la fonction utilise pour calculer les distances. Utilisez \code{\link[fields]{rdist.earth}} si vous utilisez des coordonnes longitude/latitude en degrs dcimaux. Utilisez \code{\link[fields]{rdist}} pour des distances euclidiennes.}
  \item{miles}{logical. \code{TRUE} ou \code{FALSE}. Variable transmise  \code{\link[fields]{rdist.earth}} si cette fonction est appele. Calcul des distances en kilomtres si \code{FALSE} et en miles si \code{TRUE}.}
}
\details{
Si \code{type = 'all'}, les distances de chaque cluster  l'ensemble des villes spcifies dans \code{cities} sont calcules, puis la ville la plus proche de chaque cluster est slectionne. Si \code{type = 'ask'}, une fentre prsentant l'ensemble des villes contenues dans \code{cities} apparatra et vous serez invit  slectioner les villes que vous souhaitez retenir pour la dfinition des agglomrations urbaines.

Si vous utilisez la fonction \code{\link[fields]{rdist}}, \code{dist} doit tre exprim dans la mme unit que les coordonnes des clusters et des villes. Si vos coordonnes sont exprimes en degrs dcimaux, utilisez la fonction \code{\link[fields]{rdist.earth}} et prcisez avec le paramtre \code{miles} si vous souhaitez que les rsultats soient exprims en kilomtres ou en miles. \code{dist} devra tre exprim en kilomtres ou en miles selon le cas.
}
\value{
La fonction renvoie \code{clust} en lui ajoutant trois variables nommes \emph{dist.city}, \emph{city.name} et \emph{urban.area} (voir les dtails ci-dessous). Si \code{clust} comporte dj ces trois variables, les anciennes valeurs sont remplaces par les nouvelles valeurs calcules.
  \item{dist.city}{numeric. Distance  la ville la plus proche, exprime avec la mme unit que \code{dist}.}
  \item{city.name}{character. Nom de la ville la plus proche.}
  \item{urban.area}{factor with 2 levels : \emph{in urban area}, \emph{outside urban area}. Indique si le cluster appartient ou non  l'agglomration urbaine de \code{city.name}. Est considr comme appartenant  une agglomration urbaine tout cluster  la fois urbain et situ  moins de \code{dist} de la ville considre.}
}
\note{
Pour un pays de taille moyenne, 15 kilomtres est souvent un bon compromis pour \code{dist}.
Pour le choix des agglomrations urbaines, voir le tutoriel de prevR (\file{tutoriel.prevR.pdf}).
}
\seealso{\code{\link{verif.urb}} et \code{\link{infos.prev}} pour obtenir des statistiques sur les fichiers de donnes.\cr
\code{\link{map.clust}} et \code{\link{map.cities}} pour raliser des cartes.}
\examples{
## Chargement des donnes
data(alicante)

## Carte des villes de plus de 100.000 habitants
map.cities(alicante.cities, alicante.bounds, min.population=100000,
   new.window=FALSE, main='Main cities of Alicante')

## Carte des clusters par milieu de rsidence
x11()
map.clust(alicante.clust, alicante.bounds, type='urb', new.window=FALSE,
   main='Clusters by type of residence')


## Slection des villes de plus de 100.000 habitants
main.cities <- alicante.cities[alicante.cities$population > 100000, ]

## Calcul des distances  la ville de plus de 100.000 habitants
## la plus proche et vrification des rsulats
alicante.clust <- calcul.dist.cities(alicante.clust, main.cities,
   type='all', dist=25)
verif.urb(alicante.clust)

## Slection des villes de plus de 250.000 habitants
main.cities <- alicante.cities[alicante.cities$population > 250000, ]

## Calcul des distances  la ville de plus de 250.000 habitants
## la plus proche et vrification des rsulats
alicante.clust <- calcul.dist.cities(alicante.clust, main.cities,
   type='all', dist=25)
verif.urb(alicante.clust)
infos.prev(alicante.clust)

## Carte des clusters selon leur appartenance  une agglomration urbaine
x11()
map.clust(alicante.clust, alicante.bounds, type='urb', new.window=FALSE,
   var.urb='urban.area', inverse=TRUE,
	main='Clusters in urban agglomeration')

}
\keyword{math}