\name{map.clust}
\alias{map.clust}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Permet de cartographier les zones d'enqutes ou clusters.}
\description{
Affiche sur une carte les clusters enquts selon leur milieu de rsidence, le nombre de personnes enqutes ou selon le nombre de personnes prsentant la caractristique tudie (nombre de cas positifs).
}
\usage{
map.clust(
   clust,
   boundary,
   type = "urb",
   lang = "en",
   var.urb = "residence",
   var.n = "n",
   var.obs.prevalence = "obs.prevalence",
   var.coords = c("x", "y"),
   inverse = FALSE,
   add.legend = TRUE,
   legend.location = "bottomright",
   factor.size = 0.2,
   new.window = TRUE,
   ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{clust}{data.frame. Il doit comporter une ligne par cluster. Typiquement le rsultat de \code{\link{make.clust.dbf}}.}
  \item{boundary}{data.frame. Doit contenir deux colonnes, \emph{x} et \emph{y}. Srie de points dfinissant un polygone correspondant aux limites de la zone tudie.}
  \item{type}{character. Peut prendre les valeurs \emph{urb}, \emph{flower} ou \emph{count}. Voir les dtails.}
  \item{lang}{character. Permet de choisir la langue de l'interface utilisateur. \code{fr} pour le franais, \code{en} pour l'anglais.}
  \item{var.urb}{character. Nom de la colonne de \code{clust} utilise pour reprsenter le type des clusters si \code{type= 'urb'}. Non requise sinon.}
  \item{var.n}{character. Nom de la colonne de \code{clust} utilise pour reprsenter la taille des clusters si \code{type= 'count'}. Requise galement si \code{type= 'flower'}.}
  \item{var.obs.prevalence}{character. Nom de la colonne de \code{clust} correspondant  la prvalence observe de chaque cluster. Requise uniquement si \code{type= 'flower'}.}
  \item{var.coords}{character vector. Liste des noms des deux variables de \code{clust} correspondant  la longitude et la latitude de chaque cluster.}
  \item{inverse}{logical. Utilis si \code{type= 'urb'}. Si \code{TRUE}, inverse l'ordre des modalits. Voir dtails.}
  \item{add.legend}{logical. Indique si une lgende doit tre affiche.}
  \item{legend.location}{Position de la lgende. Variable transmise  \code{\link[graphics]{legend}}. Voir la section \emph{Details} de l'aide de cette fonction.\cr
Le plus simple consiste  utiliser les termes \emph{bottomright}, \emph{bottom}, \emph{bottomleft}, \emph{left}, \emph{topleft}, \emph{top}, \emph{topright}, \emph{right} and \emph{center}.}
  \item{factor.size}{numeric. Utilis si \code{type= 'count'}. Facteur d'agrandissement ou de rduction de la taille des cercles.}
  \item{new.window}{logical. Indique si la carte doit tre dessinne dans une nouvelle fentre.}
  \item{\dots}{Paramtres supplmentaires passs  la fonction \code{\link[graphics]{title}}. Voir l'aide de cette fonction.}
}
\details{
Dessine tout d'abord le polygone dfini par \code{boundary}.
Si \code{type = 'urb'}, reprsente les clusters, selon leur milieu de rsidence, par des points verts et rouges. Par dfaut, le vert est utilis pour coder la premire modalit, d'un point de vue alphabtique, de la colonne dfinie par \code{var.urb}. Si \code{inverse = TRUE}, le vert sera utilis pour la dernire modalit, d'un point de vue alphabtique.

Si \code{type = 'flower'}, la carte gnre reprsentera le nombre d'obervations positives par cluster. Un cluster sans cas positif sera reprsent par un point vert, un cluster avec un seul cas positif par un point mauve, un cluster avec plusieurs cas positifs par un point mauve et autant de 'rayons' rouges que de cas positifs. Voir \code{\link[graphics]{sunflowerplot}} pour plus de dtails sur ce type de graphiques.

Si \code{type = 'count'}, la carte reprsente le nombre d'observations de chaque cluster par un cercle proportionnel au nombre d'observatuibs du cluster. La taille des cercles peut tre contrle par \code{factor.size}. Pour un exemple d'exportation des rsultats vers un logiciel de dessin afin d'appliquer une transparence aux cercles, voir le tutoriel de prevR (\file{tutoriel.prevR.pdf}).
}
\examples{

data(alicante)

map.clust(alicante.clust, alicante.bounds,
	type='count',
	new.window=FALSE,
	main='Number of tested persons by cluster',
	factor.size=0.15)

map.clust(alicante.clust, alicante.bounds,
	type='flower',
	main='Number of HIV positive persons by cluster')

map.clust(alicante.clust, alicante.bounds,
	type='urb',
	main='Clusters by type of residence')

map.clust(alicante.clust, alicante.bounds,
	type='urb',
	var.urb='urban.area',
	inverse=TRUE,
	main='Clusters in urban agglomeration')

}
\keyword{dplot}